package cn.qqck.kotlin.tools

/**
 * 将当前字节数组转换为 `JsonValue` 对象。
 * 该方法首先将字节数组解码为字符串，然后尝试解析为 `JsonValue`。
 *
 * @return 一个表示 JSON 数据结构的 `JsonValue` 对象。
 */
fun ByteArray.json(): dev.botta.json.values.JsonValue {
    return this.string().json()
}

/**
 * 将当前字符串解析为一个 `JsonValue` 对象。
 * 如果解析失败，则返回一个空的 `JsonObject`。
 *
 * @return 如果字符串可以被成功解析为 JSON，则返回对应的 `JsonValue` 实例；
 *         如果发生解析异常，则返回一个空的 `JsonObject` 实例。
 */
fun String.json(): dev.botta.json.values.JsonValue {
    return try {
        dev.botta.json.Json.parse(this)
    } catch (_: Exception) {
        dev.botta.json.values.JsonObject()
    }
}
